@@ -112,11 +112,11 @@ FORM (GRAPHICS_EACH__FormantPath_drawAsGrid, U"FormantPath: Draw as grid", nullp
 	INTEGER (numberOfRows, U"Number of rows", U"0")
 	INTEGER (numberOfColumns, U"Number of columns", U"0")
 	POSITIVE (xSpaceFraction, U"X space fraction", U"0.1")
-	POSITIVE (ySpaceFraction, U"Y space fraction", U"0.1")
+	POSITIVE (ySpaceFraction, U"Y space fraction", U"0.2")
 	POSITIVE (lineEvery_Hz, U"Horizontal line every (Hz)", U"1000.0")
 	REAL (xCursor, U"X cursor line at (s)", U"-0.1 (=no line)")
 	REAL (yCursor, U"Y cursor at (Hz)", U"-100.0 (=no line)")
-	NATURALVECTOR (parameters, U"Coefficients by track", WHITESPACE_SEPARATED_, U"7 7 7 7")
+	NATURALVECTOR (parameters, U"Coefficients by track", WHITESPACE_SEPARATED_, U"3 3 3 3 3")
 	BOOLEAN (markCandidatesWithinPath, U"Mark candidates within path", false)
 	COLOUR (markColour, U"Mark colour", U"{0.984,0.984, 0.7}")
 	BOOLEAN (showStress, U"Show stress", true)
@@ -714,7 +714,7 @@ FORM (CONVERT_EACH_TO_ONE__PowerCepstrogram_to_PowerCepstrum_slice, U"PowerCepst
 DO
 	CONVERT_EACH_TO_ONE (PowerCepstrogram)
 		autoPowerCepstrum result = PowerCepstrogram_to_PowerCepstrum_slice (me, time);
-	CONVERT_EACH_TO_ONE_END (my name.get(), NUMnumber_as_stringWithDotReplacedByUnderscore (time));
+	CONVERT_EACH_TO_ONE_END (my name.get(), U"_", NUMnumber_as_stringWithDotReplacedByUnderscore (time));
 }
 
 FORM (LIST__PowerCepstrogram_listCPP, U"PowerCepstrogram: List cepstral peak prominences", U"PowerCepstrogram: To Table (cepstral peak prominences)...") {
@@ -1045,7 +1045,7 @@ FORM (CONVERT_EACH_TO_ONE__LPC_to_Polynomial_slice, U"LPC: To Polynomial", U"LPC
 DO
 	CONVERT_EACH_TO_ONE (LPC)
 		autoPolynomial result = LPC_to_Polynomial (me, time);
-	CONVERT_EACH_TO_ONE_END (my name.get(), NUMnumber_as_stringWithDotReplacedByUnderscore (time))
+	CONVERT_EACH_TO_ONE_END (my name.get(), U"_", NUMnumber_as_stringWithDotReplacedByUnderscore (time))
 }
 
 FORM (CONVERT_EACH_TO_ONE__LPC_to_Spectrum_slice, U"LPC: To Spectrum", U"LPC: To Spectrum (slice)...") {
@@ -1057,7 +1057,7 @@ FORM (CONVERT_EACH_TO_ONE__LPC_to_Spectrum_slice, U"LPC: To Spectrum", U"LPC: To
 DO
 	CONVERT_EACH_TO_ONE (LPC)
 		autoSpectrum result = LPC_to_Spectrum (me, time, minimumFrequencyResolution, bandwidthReduction, deemphasisFrequency);
-	CONVERT_EACH_TO_ONE_END (my name.get(), NUMnumber_as_stringWithDotReplacedByUnderscore (time))
+	CONVERT_EACH_TO_ONE_END (my name.get(), U"_", NUMnumber_as_stringWithDotReplacedByUnderscore (time))
 }
 
 FORM (CONVERT_EACH_TO_ONE__LPC_to_Spectrogram, U"LPC: To Spectrogram", U"LPC: To Spectrogram...") {
@@ -1080,7 +1080,7 @@ FORM (CONVERT_EACH_TO_ONE__LPC_to_VocalTract_slice_special, U"LPC: To VocalTract
 DO
 	CONVERT_EACH_TO_ONE (LPC)
 		autoVocalTract result = LPC_to_VocalTract_slice_special (me, time, glottalDamping, radiationDamping, internalDamping);
-	CONVERT_EACH_TO_ONE_END (my name.get(), NUMnumber_as_stringWithDotReplacedByUnderscore (time))
+	CONVERT_EACH_TO_ONE_END (my name.get(), U"_", NUMnumber_as_stringWithDotReplacedByUnderscore (time))
 }
 
 FORM (CONVERT_EACH_TO_ONE__LPC_to_VocalTract_slice, U"LPC: To VocalTract", U"LPC: To VocalTract (slice)...") {
@@ -1090,7 +1090,7 @@ FORM (CONVERT_EACH_TO_ONE__LPC_to_VocalTract_slice, U"LPC: To VocalTract", U"LPC
 DO
 	CONVERT_EACH_TO_ONE (LPC)
 		autoVocalTract result = LPC_to_VocalTract_slice (me, time, length);
-	CONVERT_EACH_TO_ONE_END (my name.get(), NUMnumber_as_stringWithDotReplacedByUnderscore (time))
+	CONVERT_EACH_TO_ONE_END (my name.get(), U"_", NUMnumber_as_stringWithDotReplacedByUnderscore (time))
 }
 
 DIRECT (CONVERT_EACH_TO_ONE__LPC_downto_Matrix_lpc) {
@@ -1451,8 +1451,9 @@ void praat_uvafon_LPC_init () {
 	
 	Thing_recognizeClassesByName (classCepstrumc, classPowerCepstrum, classCepstrogram, classFormantPath, classFormantPathEditor, classPowerCepstrogram, classLPC, classLFCC, classLineSpectralFrequencies, classMFCC, classVocalTractTier, nullptr);
 	
+	structFormantPathArea  :: f_preferences ();
 	structFormantPathEditor  :: f_preferences ();
-		
+
 
 	praat_addAction1 (classCepstrumc, 0, U"Analyse", nullptr,0, nullptr);
 	praat_addAction1 (classCepstrumc, 0, U"To LPC", nullptr,0, 
@@ -1463,7 +1464,7 @@ void praat_uvafon_LPC_init () {
 	praat_addAction1 (classCepstrumc, 0, U"To Matrix", nullptr,0,
 			CONVERT_EACH_TO_ONE__Cepstrumc_to_Matrix);
 
-	praat_addAction1 (classFormant, 0, U"List formant slope...", U"Get standard deviation...", praat_DEPTH_1 + praat_HIDDEN,
+	praat_addAction1 (classFormant, 0, U"List formant slope...", U"Get standard deviation...", GuiMenu_DEPTH_1 | GuiMenu_HIDDEN,
 			QUERY_ONE_FOR_REAL_VECTOR__Formant_listFormantSlope);
 	praat_addAction1 (classFormant, 0, U"Analyse", nullptr,0, nullptr);
 	praat_addAction1 (classFormant, 0, U"To LPC...", nullptr,0, 
@@ -1565,9 +1566,9 @@ void praat_uvafon_LPC_init () {
 			CONVERT_EACH_TO_ONE__LPC_to_Polynomial_slice);
 	praat_addAction1 (classLPC, 0, U"Down to Matrix (lpc)", nullptr, 0, 
 			CONVERT_EACH_TO_ONE__LPC_downto_Matrix_lpc);
-	praat_addAction1 (classLPC, 0, U"Down to Matrix (rc)", nullptr, praat_HIDDEN, 
+	praat_addAction1 (classLPC, 0, U"Down to Matrix (rc)", nullptr, GuiMenu_HIDDEN,
 			CONVERT_EACH_TO_ONE__LPC_downto_Matrix_rc);
-	praat_addAction1 (classLPC, 0, U"Down to Matrix (area)", nullptr, praat_HIDDEN,
+	praat_addAction1 (classLPC, 0, U"Down to Matrix (area)", nullptr, GuiMenu_HIDDEN,
 			CONVERT_EACH_TO_ONE__LPC_downto_Matrix_area);
 	praat_addAction1 (classLPC, 0, U"Analyse", nullptr, 0, nullptr);
 	praat_addAction1 (classLPC, 0, U"To Formant", nullptr, 0, 
@@ -1586,7 +1587,7 @@ void praat_uvafon_LPC_init () {
 			CONVERT_ONE_AND_ONE_TO_ONE__LPC_Sound_filter);
 	praat_addAction2 (classLPC, 1, classSound, 1, U"Filter (inverse)", nullptr, 0,
 			CONVERT_ONE_AND_ONE_TO_ONE__LPC_Sound_filterInverse);
-	praat_addAction2 (classLPC, 1, classSound, 1, U"To LPC (robust)...", nullptr, praat_HIDDEN + praat_DEPTH_1,
+	praat_addAction2 (classLPC, 1, classSound, 1, U"To LPC (robust)...", nullptr, GuiMenu_DEPTH_1 | GuiMenu_HIDDEN,
 			CONVERT_ONE_AND_ONE_TO_ONE__LPC_Sound_to_LPC_robust);
 	praat_addAction2 (classLPC, 1, classSound, 1, U"Filter with filter at time...", nullptr, 0, 
 			CONVERT_ONE_AND_ONE_TO_ONE__LPC_Sound_filterWithFilterAtTime);
@@ -1599,9 +1600,9 @@ void praat_uvafon_LPC_init () {
 			GRAPHICS_EACH__PowerCepstrum_draw);
 	praat_addAction1 (classPowerCepstrum, 0, U"Draw trend line...", nullptr, 0, 
 			GRAPHICS_EACH__PowerCepstrum_drawTrendLine);
-	praat_addAction1 (classPowerCepstrum, 0, U"Draw tilt line...", nullptr, praat_DEPRECATED_2019, 
+	praat_addAction1 (classPowerCepstrum, 0, U"Draw tilt line...", nullptr, GuiMenu_DEPRECATED_2019,
 			GRAPHICS_EACH__PowerCepstrum_drawTrendLine);
-	praat_addAction1 (classCepstrum, 0, U"Draw (linear)...", nullptr, praat_HIDDEN, 
+	praat_addAction1 (classCepstrum, 0, U"Draw (linear)...", nullptr, GuiMenu_HIDDEN, 
 			GRAPHICS_EACH__Cepstrum_drawLinear);
 	praat_addAction1 (classCepstrum, 0, U"Down to PowerCepstrum", nullptr, 0, 
 			CONVERT_EACH_TO_ONE__Cepstrum_downto_PowerCepstrum);
@@ -1626,7 +1627,7 @@ void praat_uvafon_LPC_init () {
 				QUERY_ONE_FOR_REAL__PowerCepstrum_getPeakInQuefrencyInterval);
 		praat_addAction1 (classPowerCepstrum, 0, U"Get quefrency of peak...", nullptr, 1, 
 				QUERY_ONE_FOR_REAL__PowerCepstrum_getQuefrencyOfPeak);
-		praat_addAction1 (classPowerCepstrum, 0, U"Get peak prominence (hillenbrand)...", nullptr, praat_DEPTH_1 + praat_HIDDEN,
+		praat_addAction1 (classPowerCepstrum, 0, U"Get peak prominence (hillenbrand)...", nullptr, GuiMenu_DEPTH_1 | GuiMenu_HIDDEN,
 				QUERY_ONE_FOR_REAL__PowerCepstrum_getPeakProminence_hillenbrand);
 		praat_addAction1 (classPowerCepstrum, 0, U"Get peak prominence...", nullptr, 1, 
 				QUERY_ONE_FOR_REAL__PowerCepstrum_getPeakProminence);
@@ -1638,29 +1639,29 @@ void praat_uvafon_LPC_init () {
 				QUERY_ONE_FOR_REAL__PowerCepstrum_getValueInBin);
 		praat_addAction1 (classPowerCepstrum, 0, U"Get rhamonics to noise ratio...", nullptr, 1, 
 				QUERY_ONE_FOR_REAL__PowerCepstrum_getRNR);
-		praat_addAction1 (classPowerCepstrum, 0, U"Get tilt line slope...", nullptr, praat_DEPRECATED_2019,
+		praat_addAction1 (classPowerCepstrum, 0, U"Get tilt line slope...", nullptr, GuiMenu_DEPRECATED_2019,
 				QUERY_ONE_FOR_REAL__PowerCepstrum_getTrendLineSlope);
-		praat_addAction1 (classPowerCepstrum, 0, U"Get tilt line intercept...", nullptr, praat_DEPRECATED_2019,
+		praat_addAction1 (classPowerCepstrum, 0, U"Get tilt line intercept...", nullptr, GuiMenu_DEPRECATED_2019,
 				QUERY_ONE_FOR_REAL__PowerCepstrum_getTrendLineIntercept);
 	praat_addAction1 (classPowerCepstrum, 1, U"Modify -", nullptr, 0, nullptr);
 		praat_addAction1 (classPowerCepstrum, 0, U"Formula...", nullptr, 1, 
 				MODIFY_EACH__PowerCepstrum_formula);
 		praat_addAction1 (classPowerCepstrum, 0, U"Subtract trend (in-place)...", nullptr, 1, 
 				MODIFY_EACH__PowerCepstrum_subtractTrend_inplace);
-		praat_addAction1 (classPowerCepstrum, 0, U"Subtract tilt (in-line)...", nullptr, praat_DEPTH_1 + praat_DEPRECATED_2017,
+		praat_addAction1 (classPowerCepstrum, 0, U"Subtract tilt (in-line)...", nullptr, GuiMenu_DEPTH_1 | GuiMenu_DEPRECATED_2017,
 				MODIFY_EACH__PowerCepstrum_subtractTrend_inplace);
 		praat_addAction1 (classPowerCepstrum, 0, U"Smooth (in-place)...", nullptr, 1, 
 				MODIFY_EACH__PowerCepstrum_smooth_inplace);
-		praat_addAction1 (classPowerCepstrum, 0, U"Smooth (in-line)...", nullptr, praat_DEPTH_1 + praat_DEPRECATED_2017,
+		praat_addAction1 (classPowerCepstrum, 0, U"Smooth (in-line)...", nullptr, GuiMenu_DEPTH_1 | GuiMenu_DEPRECATED_2017,
 				MODIFY_EACH__PowerCepstrum_smooth_inplace);
 
 	praat_addAction1 (classPowerCepstrum, 0, U"Subtract trend...", nullptr, 0, 
 			CONVERT_EACH_TO_ONE__PowerCepstrum_subtractTrend);
-	praat_addAction1 (classPowerCepstrum, 0, U"Subtract tilt...", nullptr, praat_DEPRECATED_2019,
+	praat_addAction1 (classPowerCepstrum, 0, U"Subtract tilt...", nullptr, GuiMenu_DEPRECATED_2019,
 			CONVERT_EACH_TO_ONE__PowerCepstrum_subtractTrend);
 	praat_addAction1 (classPowerCepstrum, 0, U"Smooth...", nullptr, 0, 
 			CONVERT_EACH_TO_ONE__PowerCepstrum_smooth);
-	praat_addAction1 (classCepstrum, 0, U"To Spectrum", nullptr, praat_HIDDEN, 
+	praat_addAction1 (classCepstrum, 0, U"To Spectrum", nullptr, GuiMenu_HIDDEN,
 			CONVERT_EACH_TO_ONE__Cepstrum_to_Spectrum);
 	praat_addAction1 (classPowerCepstrum, 0, U"To Matrix", nullptr, 0, 
 			CONVERT_EACH_TO_ONE__PowerCepstrum_to_Matrix);
@@ -1672,7 +1673,7 @@ void praat_uvafon_LPC_init () {
 	praat_addAction1 (classPowerCepstrogram, 0, U"Tabulate -", nullptr, 0, nullptr);
 		praat_addAction1 (classPowerCepstrogram, 1, U"List cepstral peak prominences...", nullptr, 1, LIST__PowerCepstrogram_listCPP);
 		praat_addAction1 (classPowerCepstrogram, 0, U"To Table (cepstral peak prominences)...", nullptr, 1, NEW__PowerCepstrogram_to_Table_CPP);
-	praat_addAction1 (classPowerCepstrogram, 0, U"To Table (hillenbrand)...", nullptr, praat_DEPTH_1 + praat_HIDDEN,
+	praat_addAction1 (classPowerCepstrogram, 0, U"To Table (hillenbrand)...", nullptr, GuiMenu_DEPTH_1 | GuiMenu_HIDDEN,
 			CONVERT_EACH_TO_ONE__PowerCepstrogram_to_Table_hillenbrand);
 	praat_addAction1 (classPowerCepstrogram, 1, U"Query -", nullptr, 0, nullptr);
 		praat_TimeFrameSampled_query_init (classPowerCepstrogram);
@@ -1686,7 +1687,7 @@ void praat_uvafon_LPC_init () {
 					QUERY_ONE_FOR_INTEGER__PowerCepstrogram_getNumberOfQuefrencyBins);
 			praat_addAction1 (classPowerCepstrogram, 1, U"Get quefrency step", nullptr, 2,
 					QUERY_ONE_FOR_REAL__PowerCepstrogram_getQuefrencyStep);
-		praat_addAction1 (classPowerCepstrogram, 0, U"Get CPPS (hillenbrand)...", nullptr, praat_DEPTH_1 + praat_HIDDEN,
+		praat_addAction1 (classPowerCepstrogram, 0, U"Get CPPS (hillenbrand)...", nullptr, GuiMenu_DEPTH_1 | GuiMenu_HIDDEN,
 				QUERY_ONE_FOR_REAL__PowerCepstrogram_getCPPS_hillenbrand);
 		praat_addAction1 (classPowerCepstrogram, 0, U"Get CPPS...", nullptr, 1,
 				QUERY_ONE_FOR_REAL__PowerCepstrogram_getCPPS);
@@ -1696,9 +1697,9 @@ void praat_uvafon_LPC_init () {
 				MODIFY__EACH_WEAK__PowerCepstrogram_formula);
 		praat_addAction1 (classPowerCepstrogram, 0, U"Subtract trend (in-place)...", nullptr, 1,
 				MODIFY_EACH__PowerCepstrogram_subtractTrend_inplace);
-		praat_addAction1 (classPowerCepstrogram, 0, U"Subtract tilt (in-place)...", nullptr, praat_DEPRECATED_2019,
+		praat_addAction1 (classPowerCepstrogram, 0, U"Subtract tilt (in-place)...", nullptr, GuiMenu_DEPRECATED_2019,
 				MODIFY_EACH__PowerCepstrogram_subtractTrend_inplace);
-		praat_addAction1 (classPowerCepstrogram, 0, U"Subtract tilt (in-line)...", nullptr, praat_DEPTH_1 + praat_DEPRECATED_2017,
+		praat_addAction1 (classPowerCepstrogram, 0, U"Subtract tilt (in-line)...", nullptr, GuiMenu_DEPTH_1 | GuiMenu_DEPRECATED_2017,
 				MODIFY_EACH__PowerCepstrogram_subtractTrend_inplace);
 	praat_addAction1 (classPowerCepstrogram, 0, U"To PowerCepstrum (slice)...", nullptr, 0, 
 			CONVERT_EACH_TO_ONE__PowerCepstrogram_to_PowerCepstrum_slice);
@@ -1706,14 +1707,14 @@ void praat_uvafon_LPC_init () {
 			CONVERT_EACH_TO_ONE__PowerCepstrogram_smooth);
 	praat_addAction1 (classPowerCepstrogram, 0, U"Subtract trend...", nullptr, 0, 
 			CONVERT_EACH_TO_ONE__PowerCepstrogram_subtractTrend);
-	praat_addAction1 (classPowerCepstrogram, 0, U"Subtract tilt...", nullptr, praat_DEPRECATED_2019, 
+	praat_addAction1 (classPowerCepstrogram, 0, U"Subtract tilt...", nullptr, GuiMenu_DEPRECATED_2019,
 			CONVERT_EACH_TO_ONE__PowerCepstrogram_subtractTrend);
 	praat_addAction1 (classPowerCepstrogram, 0, U"To Matrix", nullptr, 0, 
 			CONVERT_EACH_TO_ONE__PowerCepstrogram_to_Matrix);
 
 	praat_addAction1 (classSound, 0, U"To PowerCepstrogram...", U"To Harmonicity (gne)...", 1, 
 			CONVERT_EACH_TO_ONE__Sound_to_PowerCepstrogram);
-	praat_addAction1 (classSound, 0, U"To PowerCepstrogram (hillenbrand)...", U"To Harmonicity (gne)...", praat_HIDDEN + praat_DEPTH_1,
+	praat_addAction1 (classSound, 0, U"To PowerCepstrogram (hillenbrand)...", U"To Harmonicity (gne)...", GuiMenu_DEPTH_1 | GuiMenu_HIDDEN,
 			CONVERT_EACH_TO_ONE__Sound_to_PowerCepstrogram_hillenbrand);
 	praat_addAction1 (classSound, 0, U"To Formant (robust)...", U"To Formant (sl)...", 2,
 			CONVERT_EACH_TO_ONE__Sound_to_Formant_robust);
