@@ -1,6 +1,6 @@
 /* ArtwordEditor.cpp
  *
- * Copyright (C) 1992-2013,2015-2021 Paul Boersma
+ * Copyright (C) 1992-2013,2015-2022 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,47 +21,41 @@
 
 Thing_implement (ArtwordEditor, Editor, 0);
 
-void structArtwordEditor :: v_destroy () noexcept {
-	ArtwordEditor_Parent :: v_destroy ();
-}
-
 static void updateList (ArtwordEditor me) {
-	Artword artword = (Artword) my data;
-	ArtwordData a = & artword -> data [(int) my muscle];
+	ArtwordData a = & my artword -> data [(int) my muscle];
 	GuiList_deleteAllItems (my list);
 	for (int16 i = 1; i <= a -> numberOfTargets; i ++) {
 		GuiList_insertItem (my list,
 			Melder_cat (Melder_single (a -> times [i]), U"  ", Melder_single (a -> targets [i])),
-			i);
+			i
+		);
 	}
 	Graphics_updateWs (my graphics.get());
 }
 
 static void gui_button_cb_removeTarget (ArtwordEditor me, GuiButtonEvent /* event */) {
-	Artword artword = (Artword) my data;
 	autoINTVEC selectedPositions = GuiList_getSelectedPositions (my list);
 	for (integer ipos = selectedPositions.size; ipos > 0; ipos --) {
 		integer position = selectedPositions [ipos];
 		Melder_assert (position >= 1 && position <= INT16_MAX);
-		Artword_removeTarget (artword, my muscle, (int16) position);   // guarded conversion
+		Artword_removeTarget (my artword, my muscle, (int16) position);   // guarded conversion
 	}
 	updateList (me);
 	Editor_broadcastDataChanged (me);
 }
 
 static void gui_button_cb_addTarget (ArtwordEditor me, GuiButtonEvent /* event */) {
-	Artword artword = (Artword) my data;
 	autostring32 timeText = GuiText_getString (my time);
 	double tim = Melder_atof (timeText.get());
 	autostring32 valueText = GuiText_getString (my value);
 	const double value = Melder_atof (valueText.get());
-	ArtwordData a = & artword -> data [(int) my muscle];
+	ArtwordData a = & my artword -> data [(int) my muscle];
 	int i = 1, oldCount = a -> numberOfTargets;
-	Artword_setTarget (artword, my muscle, tim, value);
+	Artword_setTarget (my artword, my muscle, tim, value);
 
 	/* Optimization instead of "updateList (me)". */
 
-	Melder_clip (0.0, & tim, artword -> totalTime);
+	Melder_clip (0.0, & tim, my artword -> totalTime);
 	while (tim != a -> times [i]) {
 		i ++;
 		Melder_assert (i <= a -> numberOfTargets);   // can fail if tim is in an extended precision register
@@ -85,16 +79,14 @@ static void gui_radiobutton_cb_toggle (ArtwordEditor me, GuiRadioButtonEvent eve
 static void gui_drawingarea_cb_expose (ArtwordEditor me, GuiDrawingArea_ExposeEvent /* event */) {
 	if (! my graphics)
 		return;
-	Artword artword = (Artword) my data;
 	Graphics_clearWs (my graphics.get());
-	Artword_draw (artword, my graphics.get(), my muscle, true);
+	Artword_draw (my artword, my graphics.get(), my muscle, true);
 }
 
 static void gui_drawingarea_cb_mouse (ArtwordEditor me, GuiDrawingArea_MouseEvent event) {
 	if (! my graphics)
 		return;
-	Artword artword = (Artword) my data;
-	Graphics_setWindow (my graphics.get(), 0, artword -> totalTime, -1.0, 1.0);
+	Graphics_setWindow (my graphics.get(), 0, my artword -> totalTime, -1.0, 1.0);
 	Graphics_setInner (my graphics.get());
 	double xWC, yWC;
 	Graphics_DCtoWC (my graphics.get(), event -> x, event -> y, & xWC, & yWC);
@@ -103,7 +95,7 @@ static void gui_drawingarea_cb_mouse (ArtwordEditor me, GuiDrawingArea_MouseEven
 	GuiText_setString (my value, Melder_fixed (yWC, 6));
 }
 
-void structArtwordEditor :: v_dataChanged () {
+void structArtwordEditor :: v1_dataChanged () {
 	updateList (this);
 	Graphics_updateWs (graphics.get());
 }
@@ -113,20 +105,20 @@ void structArtwordEditor :: v_createChildren () {
 	GuiLabel_createShown (our windowForm, 40, 100, dy + 3, dy + 3 + Gui_LABEL_HEIGHT, U"Targets:", 0);
 	GuiLabel_createShown (our windowForm, 5, 65, dy + 20, dy + 20 + Gui_LABEL_HEIGHT, U"Times:", 0);
 	GuiLabel_createShown (our windowForm, 80, 140, dy + 20, dy + 20 + Gui_LABEL_HEIGHT, U"Values:", 0);
-	list = GuiList_createShown (our windowForm, 0, 140, dy + 40, dy + 340, true, nullptr);
+	our list = GuiList_createShown (our windowForm, 0, 140, dy + 40, dy + 340, true, nullptr);
 
 	GuiButton_createShown (our windowForm, 10, 130, dy + 410, dy + 410 + Gui_PUSHBUTTON_HEIGHT, U"Remove target", gui_button_cb_removeTarget, this, 0);
 
-	drawingArea = GuiDrawingArea_createShown (our windowForm, 170, 470, dy + 10, dy + 310,
+	our drawingArea = GuiDrawingArea_createShown (our windowForm, 170, 470, dy + 10, dy + 310,
 		gui_drawingarea_cb_expose, gui_drawingarea_cb_mouse,
 		nullptr, nullptr, this, 0
 	);
 
 	GuiLabel_createShown (our windowForm, 220, 270, dy + 340, dy + 340 + Gui_LABEL_HEIGHT, U"Time:", 0);
-	time = GuiText_createShown (our windowForm, 270, 370, dy + 340, dy + 340 + Gui_TEXTFIELD_HEIGHT, 0);
+	our time = GuiText_createShown (our windowForm, 270, 370, dy + 340, dy + 340 + Gui_TEXTFIELD_HEIGHT, 0);
 
 	GuiLabel_createShown (our windowForm, 220, 270, dy + 370, dy + 370 + Gui_LABEL_HEIGHT, U"Value:", 0);
-	value = GuiText_createShown (our windowForm, 270, 370, dy + 370, dy + 370 + Gui_TEXTFIELD_HEIGHT, 0);
+	our value = GuiText_createShown (our windowForm, 270, 370, dy + 370, dy + 370 + Gui_TEXTFIELD_HEIGHT, 0);
 
 	GuiButton_createShown (our windowForm, 240, 360, dy + 410, dy + 410 + Gui_PUSHBUTTON_HEIGHT, U"Add target", gui_button_cb_addTarget, this, GuiButton_DEFAULT);
 
@@ -143,10 +135,11 @@ void structArtwordEditor :: v_createChildren () {
 	GuiRadioButton_set (button [(int) muscle]);
 }
 
-autoArtwordEditor ArtwordEditor_create (conststring32 title, Artword data) {
+autoArtwordEditor ArtwordEditor_create (conststring32 title, Artword artword) {
 	try {
 		autoArtwordEditor me = Thing_new (ArtwordEditor);
-		Editor_init (me.get(), 20, 40, 650, 600, title, data);
+		my artword = artword;
+		Editor_init (me.get(), 20, 40, 650, 600, title, artword);
 		//XtUnmanageChild (my menuBar);
 		my graphics = Graphics_create_xmdrawingarea (my drawingArea);
 		updateList (me.get());
