@@ -2,7 +2,7 @@
 #define _Graphics_extensions_h_
 /* Graphics_extensions.h
  *
- * Copyright (C) 2012-2020 David Weenink
+ * Copyright (C) 2012-2022 David Weenink
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,13 @@
 #include "Graphics.h"
 #include "Graphics_extensions_enums.h"
 
+/*
+	Get a font size to display at least 'maxNumberOfLines' of text that consistes of 
+	'maxNumberOfCharacters_line' characters per line.
+*/
+double Graphics_getFontSizeInsideBox (Graphics g, double widthWC, double heightWC, double maxNumberOfCharacters_line, double maxNumberOfLines);
+
+
 /**
 	Draw a box plot of data [1..ndata]. The vertical center line of the plot
 	is at position 'x'. The rectangle box is 2*w wide, the whisker 2*r.
