@@ -23,10 +23,14 @@
 #include "Intensity.h"
 
 Thing_define (AnalyticSound, Sound) {
+	double v_getValueAtSample (integer isample, integer which, int unit)
+		override;
 };
 
 autoAnalyticSound AnalyticSound_create (double xmin, double xmax, integer nx, double dx, double x1);
 
+void Sound_into_AnalyticSound (Sound me, AnalyticSound thee);
+
 autoAnalyticSound Sound_to_AnalyticSound (Sound me);
 
 autoSound AnalyticSound_to_Sound (AnalyticSound me);
