@@ -1,6 +1,6 @@
 /* OptimalCeilingTierEditor.cpp
  *
- * Copyright (C) 2015-2019 David Weenink
+ * Copyright (C) 2015-2019 David Weenink, 2022 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,22 +23,27 @@ Thing_implement (OptimalCeilingTierEditor, RealTierEditor, 0);
 
 static void menu_cb_OptimalCeilingTierHelp (OptimalCeilingTierEditor, EDITOR_ARGS_DIRECT) { Melder_help (U"OptimalCeilingTier"); }
 
-void structOptimalCeilingTierEditor :: v_createHelpMenuItems (EditorMenu menu) {
-	OptimalCeilingTierEditor_Parent :: v_createHelpMenuItems (menu);
+void structOptimalCeilingTierEditor :: v_createMenuItems_help (EditorMenu menu) {
+	OptimalCeilingTierEditor_Parent :: v_createMenuItems_help (menu);
 	EditorMenu_addCommand (menu, U"OptimalCeilingTier help", 0, menu_cb_OptimalCeilingTierHelp);
 }
 
 void structOptimalCeilingTierEditor :: v_play (double startTime, double endTime) {
-	if (our d_sound.data)
-		Sound_playPart (our d_sound.data, startTime, endTime, theFunctionEditor_playCallback, this);
+	if (our soundArea())
+		Sound_playPart (our soundArea() -> sound(), startTime, endTime, theFunctionEditor_playCallback, this);
 	//else
 	//	OptimalCeilingTier_playPart (data, startTime, endTime, false);
 }
 
-autoOptimalCeilingTierEditor OptimalCeilingTierEditor_create (conststring32 title, OptimalCeilingTier octier, Sound sound, bool ownSound) {
+autoOptimalCeilingTierEditor OptimalCeilingTierEditor_create (conststring32 title,
+	OptimalCeilingTier optimalCeilingTier, Sound soundToCopy)
+{
 	try {
 		autoOptimalCeilingTierEditor me = Thing_new (OptimalCeilingTierEditor);
-		RealTierEditor_init (me.get(), classOptimalCeilingTierArea, title, octier, sound, ownSound);
+		my realTierArea() = OptimalCeilingTierArea_create (true, nullptr, me.get());
+		if (soundToCopy)
+			my soundArea() = SoundArea_create (false, soundToCopy, me.get());
+		FunctionEditor_init (me.get(), title, optimalCeilingTier);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"OptimalCeilingTier window not created.");
