@@ -35,10 +35,19 @@
 #endif
 
 #include "espeak_ng.h"
+#include "speak_lib.h"
 #include "encoding.h"
-#include "speech.h"
-#include "synthesize.h"
-#include "translate.h"
+
+#include "voice.h"                    // for voice_t, DoVoiceChange, N_PEAKS
+#include "dictionary.h"               // for strncpy0, LoadDictionary
+#include "mnemonics.h"               // for LookupMnemName, MNEM_TAB
+#include "phoneme.h"                  // for REPLACE_PHONEMES, n_replace_pho...
+#include "speech.h"                   // for GetFileLength, PATHSEP
+#include "mbrola.h"                   // for LoadMbrolaTable
+#include "synthdata.h"                // for SelectPhonemeTableName, LookupP...
+#include "synthesize.h"               // for SetSpeed, SPEED_FACTORS, speed
+#include "translate.h"                // for LANGUAGE_OPTIONS, DeleteTranslator
+#include "wavegen.h"                  // for InitBreath
 
 MNEM_TAB genders[] = {
 	{ "male", ENGENDER_MALE },
@@ -55,7 +64,7 @@ int formant_rate[9]; // values adjusted for actual sample rate
 #define DEFAULT_LANGUAGE_PRIORITY  5
 
 int n_voices_list = 0;
-espeak_VOICE *voices_list [N_VOICES_LIST];
+espeak_VOICE *voices_list[N_VOICES_LIST];
 
 espeak_VOICE current_voice_selected;
 
@@ -63,7 +72,6 @@ enum {
 	V_NAME = 1,
 	V_LANGUAGE,
 	V_GENDER,
-	V_TRANSLATOR,
 	V_PHONEMES,
 	V_DICTIONARY,
 	V_VARIANTS,
@@ -84,6 +92,7 @@ enum {
 	V_BREATHW,
 
 	// these override defaults set by the translator
+	V_LOWERCASE_SENTENCE,
 	V_WORDGAP,
 	V_INTONATION,
 	V_TUNES,
@@ -94,28 +103,16 @@ enum {
 	V_STRESSRULE,
 	V_STRESSOPT,
 	V_NUMBERS,
-	V_OPTION,
 
 	V_MBROLA,
 	V_KLATT,
 	V_FAST,
 	V_SPEED,
 	V_DICTMIN,
-	V_ALPHABET2,
 
 	// these need a phoneme table to have been specified
 	V_REPLACE,
-	V_CONSONANTS,
-
-	// these are alpha features that need to be tested and categorized
-	V_LETTER_VOWEL
-
-};
-
-static MNEM_TAB options_tab[] = {
-	{ "reduce_t", LOPT_REDUCE_T },
-	{ "bracket",  LOPT_BRACKET_PAUSE },
-	{ NULL,   -1 }
+	V_CONSONANTS
 };
 
 static MNEM_TAB keyword_tab[] = {
@@ -126,11 +123,12 @@ static MNEM_TAB keyword_tab[] = {
 	{ "maintainer",   V_MAINTAINER },
 	{ "status",       V_STATUS },
 
+
+	{ "lowercaseSentence",	V_LOWERCASE_SENTENCE },
 	{ "variants",     V_VARIANTS },
 	{ "formant",      V_FORMANT },
 	{ "pitch",        V_PITCH },
 	{ "phonemes",     V_PHONEMES },
-	{ "translator",   V_TRANSLATOR },
 	{ "dictionary",   V_DICTIONARY },
 	{ "stressLength", V_STRESSLENGTH },
 	{ "stressAmp",    V_STRESSAMP },
@@ -139,7 +137,7 @@ static MNEM_TAB keyword_tab[] = {
 	{ "tunes",        V_TUNES },
 	{ "dictrules",    V_DICTRULES },
 	{ "stressRule",   V_STRESSRULE },
-	{ "stressopt",    V_STRESSOPT },
+	{ "stressOpt",    V_STRESSOPT },
 	{ "replace",      V_REPLACE },
 	{ "words",        V_WORDGAP },
 	{ "echo",         V_ECHO },
@@ -151,7 +149,6 @@ static MNEM_TAB keyword_tab[] = {
 	{ "breath",       V_BREATH },
 	{ "breathw",      V_BREATHW },
 	{ "numbers",      V_NUMBERS },
-	{ "option",       V_OPTION },
 	{ "mbrola",       V_MBROLA },
 	{ "consonants",   V_CONSONANTS },
 	{ "klatt",        V_KLATT },
@@ -165,11 +162,10 @@ static MNEM_TAB keyword_tab[] = {
 	{ "l_regressive_v",   0x100+LOPT_REGRESSIVE_VOICING },
 	{ "l_unpronouncable", 0x100+LOPT_UNPRONOUNCABLE },
 	{ "l_sonorant_min",   0x100+LOPT_SONORANT_MIN },
-	{ "l_length_mods",    0x100+LOPT_LENGTH_MODS },
 	{ "apostrophe",       0x100+LOPT_APOSTROPHE },
+	{ "brackets",       0x100+LOPT_BRACKET_PAUSE },
+	{ "bracketsAnnounced",       0x100+LOPT_BRACKET_PAUSE_ANNOUNCED },
 
-	// these are alpha features that need to be tested and categorized
-	{ "letterVowel", V_LETTER_VOWEL },
 	{ NULL, 0 }
 };
 
@@ -190,6 +186,7 @@ static char *fgets_strip(char *buf, int size, FILE *f_in)
 
 	if (fgets(buf, size, f_in) == NULL)
 		return NULL;
+
 	if (buf[0] == '#') {
 		buf[0] = 0;
 		return buf;
@@ -385,16 +382,16 @@ void VoiceReset(int tone_only)
 	voice->samplerate = samplerate_native;
 	memset(voice->klattv, 0, sizeof(voice->klattv));
 
-	speed.fast_settings[0] = 450;
-	speed.fast_settings[1] = 800;
-	speed.fast_settings[2] = 175;
+	speed.fast_settings = espeakRATE_MAXIMUM;
 
 	voice->roughness = 2;
 
 	InitBreath();
 	for (pk = 0; pk < N_PEAKS; pk++) {
 		voice->freq[pk] = 256;
+		voice->freq2[pk] = voice->freq[pk];
 		voice->height[pk] = default_heights[pk]*2;
+		voice->height2[pk] = voice->height[pk];
 		voice->width[pk] = default_widths[pk]*2;
 		voice->breath[pk] = 0;
 		voice->breathw[pk] = breath_widths[pk]; // default breath formant widths
@@ -416,8 +413,13 @@ void VoiceReset(int tone_only)
 
 	if (tone_only == 0) {
 		n_replace_phonemes = 0;
+#ifdef INCLUDE_MBROLA
 		LoadMbrolaTable(NULL, NULL, 0);
+#endif
 	}
+
+// probably unnecessary, but removing this would break tests
+voice->width[0] = (voice->width[0] * 105)/100;
 }
 
 static void VoiceFormant(char *p)
@@ -437,13 +439,21 @@ static void VoiceFormant(char *p)
 	if ((formant < 0) || (formant > 8))
 		return;
 
-	if (freq >= 0)
+	if (freq >= 0) {
 		voice->freq[formant] = (int)(freq * 2.56001);
-	if (height >= 0)
+		voice->freq2[formant] = voice->freq[formant];
+	}
+	if (height >= 0) {
 		voice->height[formant] = (int)(height * 2.56001);
+		voice->height2[formant] = voice->height[formant];
+	}
 	if (width >= 0)
 		voice->width[formant] = (int)(width * 2.56001);
 	voice->freqadd[formant] = freqadd;
+
+	// probably unnecessary, but removing this would break tests
+	if (formant == 0)
+		voice->width[0] = (voice->width[0] * 105)/100;
 }
 
 static void PhonemeReplacement(char *p)
@@ -475,12 +485,47 @@ static int Read8Numbers(char *data_in, int *data)
 	              &data[0], &data[1], &data[2], &data[3], &data[4], &data[5], &data[6], &data[7]);
 }
 
+static void ReadNumbers(char *p, int *flags, int maxValue,  MNEM_TAB *keywordtab, int key) {
+	// read a list of numbers from string p
+	// store them as flags in *flags
+	// the meaning of the  numbers is bit ordinals, not integer values
+	// give an error if number > maxValue is read
+	int n;
+	while (*p != 0) {
+		while (isspace(*p)) p++;
+		if ((n = atoi(p)) > 0) {
+			p++;
+			if (n < maxValue) {
+				*flags |= (1 << n);
+			} else {
+				fprintf(stderr, "%s: Bad option number %d\n", LookupMnemName(keywordtab, key), n);
+			}
+		}
+	while (isalnum(*p)) p++;
+	}
+}
+
+static int CheckTranslator(Translator *tr, MNEM_TAB *keywordtab, int key)
+{
+	// Return 0 if translator is set.
+	// Return 1 and print an error message for specified key if not
+	// used for parsing language options
+	if (tr)
+		return 0;
+
+	fprintf(stderr, "Cannot set %s: language not set, or is invalid.\n", LookupMnemName(keywordtab, key));
+	return 1;
+}
+
 voice_t *LoadVoice(const char *vname, int control)
 {
 	// control, bit 0  1= no_default
 	//          bit 1  1 = change tone only, not language
 	//          bit 2  1 = don't report error on LoadDictionary
 	//          bit 4  1 = vname = full path
+        //          bit 8  1 = INTERNAL: compiling phonemes; do not try to
+        //                     load the phoneme table
+        //          bit 16 1 = UNDOCUMENTED
 
 	FILE *f_voice = NULL;
 	char *p;
@@ -488,36 +533,24 @@ voice_t *LoadVoice(const char *vname, int control)
 	int ix;
 	int n;
 	int value;
-	int value2;
 	int langix = 0;
 	int tone_only = control & 2;
-	int language_set = 0;
-	int phonemes_set = 0;
-	int stress_amps_set = 0;
-	int stress_lengths_set = 0;
-	int stress_add_set = 0;
-	int conditional_rules = 0;
-	LANGUAGE_OPTIONS *langopts = NULL;
-
-	Translator *new_translator = NULL;
+	bool language_set = false;
+	bool phonemes_set = false;
 
 	char voicename[40];
 	char language_name[40];
 	char translator_name[40];
 	char new_dictionary[40];
 	char phonemes_name[40];
-	char option_name[40];
 	const char *language_type;
 	char buf[sizeof(path_home)+30];
 	char path_voices[sizeof(path_home)+12];
 
-	int dict_min = 0;
-	int stress_amps[8];
-	int stress_lengths[8];
 	int stress_add[8];
 	char names[8][40];
-	char name1[40];
-	char name2[80];
+	//char name1[40];
+	//char name2[80];
 
 	int pitch1;
 	int pitch2;
@@ -532,7 +565,7 @@ voice_t *LoadVoice(const char *vname, int control)
 		if (GetFileLength(buf) <= 0)
 			return NULL;
 	} else {
-		if (voicename[0] == 0)
+		if (voicename[0] == 0 && !(control & 8)/*compiling phonemes*/)
 			strcpy(voicename, ESPEAKNG_DEFAULT_VOICE);
 
 		sprintf(path_voices, "%s%cvoices%c", path_home, PATHSEP, PATHSEP);
@@ -546,7 +579,11 @@ voice_t *LoadVoice(const char *vname, int control)
 
 	f_voice = fopen(buf, "r");
 
-	language_type = "en"; // default
+        if (!(control & 8)/*compiling phonemes*/)
+            language_type = ESPEAKNG_DEFAULT_VOICE; // default
+        else
+            language_type = "";
+
 	if (f_voice == NULL) {
 		if (control & 3)
 			return NULL; // can't open file
@@ -562,7 +599,6 @@ voice_t *LoadVoice(const char *vname, int control)
 
 	strcpy(translator_name, language_type);
 	strcpy(new_dictionary, language_type);
-	strcpy(phonemes_name, language_type);
 
 	if (!tone_only) {
 		voice = &voicedata;
@@ -579,13 +615,9 @@ voice_t *LoadVoice(const char *vname, int control)
 			*p = 0;    // remove previous variant name
 		sprintf(buf, "+%s", &vname[3]);    // omit  !v/  from the variant filename
 		strcat(voice_identifier, buf);
-		langopts = &translator->langopts;
 	}
 	VoiceReset(tone_only);
 
-	if (!tone_only)
-		SelectPhonemeTableName(phonemes_name); // set up phoneme_tab
-
 	while ((f_voice != NULL) && (fgets_strip(buf, sizeof(buf), f_voice) != NULL)) {
 		// isolate the attribute name
 		for (p = buf; (*p != 0) && !isspace(*p); p++) ;
@@ -622,19 +654,15 @@ voice_t *LoadVoice(const char *vname, int control)
 			}
 
 			// only act on the first language line
-			if (language_set == 0) {
+			if (language_set == false) {
 				language_type = strtok(language_name, "-");
-				language_set = 1;
+				language_set = true;
 				strcpy(translator_name, language_type);
 				strcpy(new_dictionary, language_type);
 				strcpy(phonemes_name, language_type);
 				SelectPhonemeTableName(phonemes_name);
 
-				if (new_translator != NULL)
-					DeleteTranslator(new_translator);
-
-				new_translator = SelectTranslator(translator_name);
-				langopts = &new_translator->langopts;
+				translator = SelectTranslator(translator_name);
 				strncpy0(voice->language_name, language_name, sizeof(voice->language_name));
 			}
 		}
@@ -654,17 +682,6 @@ voice_t *LoadVoice(const char *vname, int control)
 			current_voice_selected.age = age;
 		}
 			break;
-		case V_TRANSLATOR:
-			if (tone_only) break;
-
-			sscanf(p, "%s", translator_name);
-
-			if (new_translator != NULL)
-				DeleteTranslator(new_translator);
-
-			new_translator = SelectTranslator(translator_name);
-			langopts = &new_translator->langopts;
-			break;
 		case V_DICTIONARY: // dictionary
 			sscanf(p, "%s", new_dictionary);
 			break;
@@ -674,6 +691,14 @@ voice_t *LoadVoice(const char *vname, int control)
 		case V_FORMANT:
 			VoiceFormant(p);
 			break;
+		case V_LOWERCASE_SENTENCE: {
+			if (CheckTranslator(translator, keyword_tab, key) != 0)
+				break;
+
+			translator->langopts.lowercase_sentence = true;
+			break;
+			}
+
 		case V_PITCH:
 			// default is  pitch 82 118
 			if (sscanf(p, "%d %d", &pitch1, &pitch2) == 2) {
@@ -683,103 +708,130 @@ voice_t *LoadVoice(const char *vname, int control)
 				voice->formant_factor = (int)((1+factor/4) * 256); // nominal formant shift for a different voice pitch
 			}
 			break;
-		case V_STRESSLENGTH: // stressLength
+		case V_STRESSLENGTH: {// stressLength
+			if (CheckTranslator(translator, keyword_tab, key) != 0)
+				break;
+
+			int stress_lengths_set = 0;
+			int stress_lengths[8];
 			stress_lengths_set = Read8Numbers(p, stress_lengths);
+
+			for (ix = 0; ix < stress_lengths_set; ix++) {
+				translator->stress_lengths[ix] = stress_lengths[ix];
+			}
+
 			break;
-		case V_STRESSAMP: // stressAmp
+		}
+		case V_STRESSAMP: { // stressAmp
+			if (CheckTranslator(translator, keyword_tab, key) != 0)
+				break;
+
+			int stress_amps_set = 0;
+			int stress_amps[8];
 			stress_amps_set = Read8Numbers(p, stress_amps);
+			for (ix = 0; ix < stress_amps_set; ix++) {
+				translator->stress_amps[ix] = stress_amps[ix];
+			}
+
 			break;
-		case V_STRESSADD: // stressAdd
+		}
+		case V_STRESSADD: { // stressAdd
+			if (CheckTranslator(translator, keyword_tab, key) != 0)
+				break;
+
+			int stress_add_set = 0;
 			stress_add_set = Read8Numbers(p, stress_add);
+
+			for (ix = 0; ix < stress_add_set; ix++) {
+				translator->stress_lengths[ix] += stress_add[ix];
+			}
+
 			break;
+		}
 		case V_INTONATION: // intonation
-			sscanf(p, "%d %d", &option_tone_flags, &option_tone2);
+			sscanf(p, "%d", &option_tone_flags);
 			if ((option_tone_flags & 0xff) != 0) {
-				if (langopts)
-					langopts->intonation_group = option_tone_flags & 0xff;
-				else
-					fprintf(stderr, "Cannot set intonation: language not set, or is invalid.\n");
+				if (CheckTranslator(translator, keyword_tab, key) != 0)
+					break;
+
+				translator->langopts.intonation_group = option_tone_flags & 0xff;
 			}
 			break;
 		case V_TUNES:
-			n = sscanf(p, "%s %s %s %s %s %s", names[0], names[1], names[2], names[3], names[4], names[5]);
-			if (langopts) {
-				langopts->intonation_group = 0;
-				for (ix = 0; ix < n; ix++) {
-					if (strcmp(names[ix], "NULL") == 0)
-						continue;
+			if (CheckTranslator(translator, keyword_tab, key) != 0)
+				break;
 
-					if ((value = LookupTune(names[ix])) < 0)
-						fprintf(stderr, "Unknown tune '%s'\n", names[ix]);
-					else
-						langopts->tunes[ix] = value;
-				}
-			} else
-				fprintf(stderr, "Cannot set tunes: language not set, or is invalid.\n");
+			n = sscanf(p, "%s %s %s %s %s %s", names[0], names[1], names[2], names[3], names[4], names[5]);
+			translator->langopts.intonation_group = 0;
+
+			for (ix = 0; ix < n; ix++) {
+				if (strcmp(names[ix], "NULL") == 0)
+					continue;
+
+				if ((value = LookupTune(names[ix])) < 0)
+					fprintf(stderr, "Unknown tune '%s'\n", names[ix]);
+				else
+					translator->langopts.tunes[ix] = value;
+			}
 			break;
+
 		case V_DICTRULES: // conditional dictionary rules and list entries
-		case V_NUMBERS:
+			if (CheckTranslator(translator, keyword_tab, key) != 0)
+				break;
+
+			ReadNumbers(p, &translator->dict_condition, 32, keyword_tab, key);
+			break;
 		case V_STRESSOPT:
-			if (langopts) {
-				// expect a list of numbers
-				while (*p != 0) {
-					while (isspace(*p)) p++;
-					if ((n = atoi(p)) > 0) {
-						p++;
-						if (n < 32) {
-							if (key == V_DICTRULES)
-								conditional_rules |= (1 << n);
-							else if (key == V_NUMBERS)
-								langopts->numbers |= (1 << n);
-							else if (key == V_STRESSOPT)
-								langopts->stress_flags |= (1 << n);
-						} else {
-							if ((key == V_NUMBERS) && (n < 64))
-								langopts->numbers2 |= (1 << (n-32));
-							else
-								fprintf(stderr, "Bad option number %d\n", n);
-						}
-					}
-					while (isalnum(*p)) p++;
+			if (CheckTranslator(translator, keyword_tab, key) != 0)
+				 break;
+
+			ReadNumbers(p, &translator->langopts.stress_flags, 32, keyword_tab, key);
+			break;
+
+		case V_NUMBERS:
+			if (CheckTranslator(translator, keyword_tab, key) != 0)
+				break;
+
+			// expect a list of numbers
+			while (*p != 0) {
+				while (isspace(*p)) p++;
+				if ((n = atoi(p)) > 0) {
+					p++;
+					if (n < 32) {
+							translator->langopts.numbers |= (1 << n);
+					} else {
+						if (n < 64)
+							translator->langopts.numbers2 |= (1 << (n-32));
+						else
+							fprintf(stderr, "numbers: Bad option number %d\n", n);					}
 				}
-				ProcessLanguageOptions(langopts);
-			} else
-				fprintf(stderr, "Cannot set stressopt: language not set, or is invalid.\n");
+				while (isalnum(*p)) p++;
+			}
+			ProcessLanguageOptions(&(translator->langopts));
+
 			break;
 		case V_REPLACE:
-			if (phonemes_set == 0) {
+			if (phonemes_set == false) {
 				// must set up a phoneme table before we can lookup phoneme mnemonics
 				SelectPhonemeTableName(phonemes_name);
-				phonemes_set = 1;
+				phonemes_set = true;
 			}
 			PhonemeReplacement(p);
 			break;
 		case V_WORDGAP: // words
-			if (langopts)
-				sscanf(p, "%d %d", &langopts->word_gap, &langopts->vowel_pause);
-			else
-				fprintf(stderr, "Cannot set wordgap: language not set, or is invalid.\n");
+			if (CheckTranslator(translator, keyword_tab, key) != 0)
+				break;
+
+			sscanf(p, "%d %d", &translator->langopts.word_gap, &translator->langopts.vowel_pause);
 			break;
 		case V_STRESSRULE:
-			if (langopts)
-				sscanf(p, "%d %d %d %d", &langopts->stress_rule,
-				       &langopts->stress_flags,
-				       &langopts->unstressed_wd1,
-				       &langopts->unstressed_wd2);
-			else
-				fprintf(stderr, "Cannot set stressrule: language not set, or is invalid.\n");
-			break;
-		case V_OPTION:
-			if (langopts) {
-				value2 = 0;
-				if (((sscanf(p, "%s %d %d", option_name, &value, &value2) >= 2) && ((ix = LookupMnem(options_tab, option_name)) >= 0)) ||
-				    ((sscanf(p, "%d %d %d", &ix, &value, &value2) >= 2) && (ix < N_LOPTS))) {
-					langopts->param[ix] = value;
-					langopts->param2[ix] = value2;
-				} else
-					fprintf(stderr, "Bad voice option: %s %s\n", buf, p);
-			} else
-				fprintf(stderr, "Cannot set option: language not set, or is invalid.\n");
+			if (CheckTranslator(translator, keyword_tab, key) != 0)
+				break;
+
+			sscanf(p, "%d %d %d", &translator->langopts.stress_rule,
+			       &translator->langopts.unstressed_wd1,
+			       &translator->langopts.unstressed_wd2);
+
 			break;
 		case V_ECHO:
 			// echo.  suggest: 135mS  11%
@@ -830,7 +882,9 @@ voice_t *LoadVoice(const char *vname, int control)
 			break;
 		case V_SPEED:
 			sscanf(p, "%d", &voice->speed_percent);
+			SetSpeed(3);
 			break;
+#ifdef INCLUDE_MBROLA
 		case V_MBROLA:
 		{
 			int srate = 16000;
@@ -838,54 +892,43 @@ voice_t *LoadVoice(const char *vname, int control)
 			name2[0] = 0;
 			sscanf(p, "%s %s %d", name1, name2, &srate);
 			espeak_ng_STATUS status = LoadMbrolaTable(name1, name2, &srate);
-			if (status != ENS_OK)
+			if (status != ENS_OK) {
 				espeak_ng_PrintStatusCodeMessage(status, stderr, NULL);
+				fclose(f_voice);
+				return NULL;
+			}
 			else
 				voice->samplerate = srate;
 		}
 			break;
+#endif
 		case V_KLATT:
 			voice->klattv[0] = 1; // default source: IMPULSIVE
 			Read8Numbers(p, voice->klattv);
 			voice->klattv[KLATT_Kopen] -= 40;
 			break;
 		case V_FAST:
-			Read8Numbers(p, speed.fast_settings);
+			sscanf(p, "%d", &speed.fast_settings);
 			SetSpeed(3);
 			break;
-		case V_DICTMIN:
-			sscanf(p, "%d", &dict_min);
+		case V_DICTMIN: {
+			if (CheckTranslator(translator, keyword_tab, key) != 0)
+				break;
+
+			if (sscanf(p, "%d", &value) == 1)
+				translator->dict_min_size = value;
+			break;
+			}
+
 			break;
 		case V_MAINTAINER:
 		case V_STATUS:
 			break;
-
-		case V_LETTER_VOWEL: {
-			char str[5] = "";
-			char c = '0';
-			char *endptr = NULL;
-			sscanf(p, "%s", str);
-			// assume a hex value if string starts with "0x"
-			if (str[0] == '0' && str[1] == 'x') {
-				c = strtoul(str, &endptr, 16);
-				if (errno == ERANGE)
-					fprintf(stderr, "letterVowel out of range.\n");
-			}
-			else  {// otherwise, assume a single letter
-				c = str[0];
-				if (c < 97 || c > 122) // valid values are a-z, ascii 97-122
-					fprintf(stderr, "letterVowel out of range.\n");
-			}
- 			new_translator->letter_bits[c] = (new_translator->letter_bits[c] & 0x40) | 0x81; // keep value for group 6 (front vowels e,i,y)
-			break;
-			}
-
 		default:
 			if ((key & 0xff00) == 0x100) {
-				if (langopts)
-					sscanf(p, "%d", &langopts->param[key &0xff]);
-				else
-					fprintf(stderr, "Cannot set voice attribute: language not set, or is invalid.\n");
+				if (CheckTranslator(translator, keyword_tab, key) != 0)
+					break;
+				sscanf(p, "%d", &translator->langopts.param[key &0xff]);
 			} else
 				fprintf(stderr, "Bad voice attribute: %s\n", buf);
 			break;
@@ -894,58 +937,35 @@ voice_t *LoadVoice(const char *vname, int control)
 	if (f_voice != NULL)
 		fclose(f_voice);
 
-	if ((new_translator == NULL) && (!tone_only)) {
+	if ((translator == NULL) && (!tone_only)) {
 		// not set by language attribute
-		new_translator = SelectTranslator(translator_name);
+		translator = SelectTranslator(translator_name);
 	}
 
-	SetSpeed(3); // for speed_percent
-
-	for (ix = 0; ix < N_PEAKS; ix++) {
-		voice->freq2[ix] = voice->freq[ix];
-		voice->height2[ix] = voice->height[ix];
-		voice->width2[ix] = voice->width[ix];
-	}
-
-	if (tone_only)
-		new_translator = translator;
-	else {
-		if ((ix = SelectPhonemeTableName(phonemes_name)) < 0) {
+	if (!tone_only) {
+		if (!!(control & 8/*compiling phonemes*/)) {
+                        /* Set by espeak_ng_CompilePhonemeDataPath when it
+                         * calls LoadVoice("", 8) to set up a dummy(?) voice.
+                         * As phontab may not yet exist this avoids the spurious
+                         * error message and guarantees consistent results by
+                         * not actually reading a potentially bogus phontab...
+                         */
+                        ix = 0;
+                } else if ((ix = SelectPhonemeTableName(phonemes_name)) < 0) {
 			fprintf(stderr, "Unknown phoneme table: '%s'\n", phonemes_name);
 			ix = 0;
 		}
+
 		voice->phoneme_tab_ix = ix;
-		new_translator->phoneme_tab_ix = ix;
-		new_translator->dict_min_size = dict_min;
-		LoadDictionary(new_translator, new_dictionary, control & 4);
-		if (dictionary_name[0] == 0) {
-			DeleteTranslator(new_translator);
-			return NULL; // no dictionary loaded
+		translator->phoneme_tab_ix = ix;
+
+		if (!(control & 8/*compiling phonemes*/)) {
+			LoadDictionary(translator, new_dictionary, control & 4);
+			if (dictionary_name[0] == 0) {
+				DeleteTranslator(translator);
+				return NULL; // no dictionary loaded
+			}
 		}
-
-		new_translator->dict_condition = conditional_rules;
-
-		voice_languages[langix] = 0;
-	}
-
-	langopts = &new_translator->langopts;
-
-	if ((value = langopts->param[LOPT_LENGTH_MODS]) != 0)
-		SetLengthMods(new_translator, value);
-
-	voice->width[0] = (voice->width[0] * 105)/100;
-
-	if (!tone_only)
-		translator = new_translator;
-
-	// relative lengths of different stress syllables
-	for (ix = 0; ix < stress_lengths_set; ix++)
-		translator->stress_lengths[ix] = stress_lengths[ix];
-	for (ix = 0; ix < stress_add_set; ix++)
-		translator->stress_lengths[ix] += stress_add[ix];
-	for (ix = 0; ix < stress_amps_set; ix++) {
-		translator->stress_amps[ix] = stress_amps[ix];
-		translator->stress_amps_r[ix] = stress_amps[ix] -1;
 	}
 
 	return voice;
@@ -1033,7 +1053,7 @@ static int VoiceScoreSorter(const void *p1, const void *p2)
 	return strcmp(v1->name, v2->name);
 }
 
-static int ScoreVoice(espeak_VOICE *voice_spec, const char *spec_language, int spec_n_parts, int spec_lang_len, espeak_VOICE *espeakvoice)
+static int ScoreVoice(espeak_VOICE *voice_spec, const char *spec_language, int spec_n_parts, int spec_lang_len, espeak_VOICE *voice_other)
 {
 	int ix;
 	const char *p;
@@ -1048,11 +1068,11 @@ static int ScoreVoice(espeak_VOICE *voice_spec, const char *spec_language, int s
 	int required_age;
 	int diff;
 
-	p = espeakvoice->languages; // list of languages+dialects for which this voice is suitable
+	p = voice_other->languages; // list of languages+dialects for which this voice is suitable
 
 	if (spec_n_parts < 0) {
 		// match on the subdirectory
-		if (memcmp(espeakvoice->identifier, spec_language, spec_lang_len) == 0)
+		if (memcmp(voice_other->identifier, spec_language, spec_lang_len) == 0)
 			return 100;
 		return 0;
 	}
@@ -1115,31 +1135,31 @@ static int ScoreVoice(espeak_VOICE *voice_spec, const char *spec_language, int s
 		return 0;
 
 	if (voice_spec->name != NULL) {
-		if (strcmp(voice_spec->name, espeakvoice->name) == 0) {
+		if (strcmp(voice_spec->name, voice_other->name) == 0) {
 			// match on voice name
 			score += 500;
-		} else if (strcmp(voice_spec->name, espeakvoice->identifier) == 0)
+		} else if (strcmp(voice_spec->name, voice_other->identifier) == 0)
 			score += 400;
 	}
 
 	if (((voice_spec->gender == ENGENDER_MALE) || (voice_spec->gender == ENGENDER_FEMALE)) &&
-	    ((espeakvoice->gender == ENGENDER_MALE) || (espeakvoice->gender == ENGENDER_FEMALE))) {
-		if (voice_spec->gender == espeakvoice->gender)
+	    ((voice_other->gender == ENGENDER_MALE) || (voice_other->gender == ENGENDER_FEMALE))) {
+		if (voice_spec->gender == voice_other->gender)
 			score += 50;
 		else
 			score -= 50;
 	}
 
-	if ((voice_spec->age <= 12) && (espeakvoice->gender == ENGENDER_FEMALE) && (espeakvoice->age > 12))
+	if ((voice_spec->age <= 12) && (voice_other->gender == ENGENDER_FEMALE) && (voice_other->age > 12))
 		score += 5; // give some preference for non-child female voice if a child is requested
 
-	if (espeakvoice->age != 0) {
+	if (voice_other->age != 0) {
 		if (voice_spec->age == 0)
 			required_age = 30;
 		else
 			required_age = voice_spec->age;
 
-		ratio = (required_age*100)/espeakvoice->age;
+		ratio = (required_age*100)/voice_other->age;
 		if (ratio < 100)
 			ratio = 10000/ratio;
 		ratio = (ratio - 100)/10; // 0=exact match, 10=out by factor of 2
@@ -1201,6 +1221,11 @@ static int SetVoiceScores(espeak_VOICE *voice_select, espeak_VOICE **voices, int
 		if (((control & 1) == 0) && (memcmp(vp->identifier, "mb/", 3) == 0))
 			continue;
 
+		if (voice_select->languages == NULL || memcmp(voice_select->languages,"all", 3) == 0) {
+			voices[nv++] = vp;
+			continue;
+		}
+
 		if ((score = ScoreVoice(voice_select, language, n_parts, lang_len, voices_list[ix])) > 0) {
 			voices[nv++] = vp;
 			vp->score = score;
@@ -1401,7 +1426,7 @@ char const *SelectVoice(espeak_VOICE *voice_select, int *found)
 }
 
 #if ! DATA_FROM_SOURCECODE_FILES
-void GetVoices(const char *path, int len_path_voices, int is_language_file)
+static void GetVoices(const char *path, int len_path_voices, int is_language_file)
 {
 	FILE *f_voice;
 	espeak_VOICE *voice_data;
@@ -1419,8 +1444,10 @@ void GetVoices(const char *path, int len_path_voices, int is_language_file)
 		return;
 
 	do {
-		if (n_voices_list >= (N_VOICES_LIST-2))
+		if (n_voices_list >= (N_VOICES_LIST-2)) {
+			fprintf(stderr, "Warning: maximum number %d of (N_VOICES_LIST = %d - 1) reached\n", n_voices_list + 1, N_VOICES_LIST);
 			break; // voices list is full
+		}
 
 		if (FindFileData.cFileName[0] != '.') {
 			sprintf(fname, "%s%c%s", path, PATHSEP, FindFileData.cFileName);
@@ -1452,8 +1479,10 @@ void GetVoices(const char *path, int len_path_voices, int is_language_file)
 		return;
 
 	while ((ent = readdir(dir)) != NULL) {
-		if (n_voices_list >= (N_VOICES_LIST-2))
+		if (n_voices_list >= (N_VOICES_LIST-2)) {
+			fprintf(stderr, "Warning: maximum number %d of (N_VOICES_LIST = %d - 1) reached\n", n_voices_list + 1, N_VOICES_LIST);
 			break; // voices list is full
+		}
 
 		if (ent->d_name[0] == '.')
 			continue;
@@ -1485,6 +1514,42 @@ void GetVoices(const char *path, int len_path_voices, int is_language_file)
 
 #pragma GCC visibility push(default)
 
+ESPEAK_NG_API espeak_ng_STATUS espeak_ng_SetVoiceByFile(const char *filename)
+{
+	int ix;
+	espeak_VOICE voice_selector;
+	char *variant_name;
+	static char buf[60];
+
+	strncpy0(buf, filename, sizeof(buf));
+
+	variant_name = ExtractVoiceVariantName(buf, 0, 1);
+
+	for (ix = 0;; ix++) {
+		// convert voice name to lower case  (ascii)
+		if ((buf[ix] = tolower(buf[ix])) == 0)
+			break;
+	}
+
+	memset(&voice_selector, 0, sizeof(voice_selector));
+	voice_selector.name = (char *)filename; // include variant name in voice stack ??
+
+	// first check for a voice with this filename
+	// This may avoid the need to call espeak_ListVoices().
+
+	if (LoadVoice(buf, 0x10) != NULL) {
+		if (variant_name[0] != 0)
+			LoadVoice(variant_name, 2);
+
+		DoVoiceChange(voice);
+		voice_selector.languages = voice->language_name;
+		SetVoiceStack(&voice_selector, variant_name);
+		return ENS_OK;
+	}
+
+	return ENS_VOICE_NOT_FOUND;
+}
+
 ESPEAK_NG_API espeak_ng_STATUS espeak_ng_SetVoiceByName(const char *name)
 {
 	espeak_VOICE *v;
