@@ -2,7 +2,7 @@
 #define _IntensityTier_h_
 /* IntensityTier.h
  *
- * Copyright (C) 1992-2005,2007,2010-2012,2015-2018,2020,2021 Paul Boersma
+ * Copyright (C) 1992-2005,2007,2010-2012,2015-2018,2020-2022 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ autoIntensityTier Intensity_PointProcess_to_IntensityTier (Intensity me, PointPr
 autoIntensityTier IntensityTier_PointProcess_to_IntensityTier (IntensityTier me, PointProcess pp);
 autoTableOfReal IntensityTier_downto_TableOfReal (IntensityTier me);
 void Sound_IntensityTier_multiply_inplace (Sound me, IntensityTier intensity);
-autoSound Sound_IntensityTier_multiply (Sound me, IntensityTier intensity, int scale);
+autoSound Sound_IntensityTier_multiply (Sound me, IntensityTier intensity, bool scaleTo09);
 autoIntensityTier RealTier_to_IntensityTier (RealTier me);
 
 /* End of file IntensityTier.h */
