@@ -1,6 +1,6 @@
 /* Ltas.cpp
  *
- * Copyright (C) 1992-2012,2015,2016,2017 Paul Boersma
+ * Copyright (C) 1992-2012,2015-2018,2022 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,9 +27,8 @@
 
 Thing_implement (Ltas, Vector, 2);
 
-void structLtas :: v_info () {
-	double meanPowerDensity;
-	structDaata :: v_info ();
+void structLtas :: v1_info () {
+	structDaata :: v1_info ();
 	MelderInfo_writeLine (U"Frequency domain:");
 	MelderInfo_writeLine (U"   Lowest frequency: ", xmin, U" Hz");
 	MelderInfo_writeLine (U"   Highest frequency: ", xmax, U" Hz");
@@ -38,7 +37,7 @@ void structLtas :: v_info () {
 	MelderInfo_writeLine (U"   Number of frequency bands: ", nx);
 	MelderInfo_writeLine (U"   Width of each band: ", dx, U" Hz");
 	MelderInfo_writeLine (U"   First band centred at: ", x1, U" Hz");
-	meanPowerDensity = Sampled_getMean (this, xmin, xmax, 0, 1, false);
+	const double meanPowerDensity = Sampled_getMean (this, xmin, xmax, 0, 1, false);
 	MelderInfo_writeLine (U"Total SPL: ", Melder_single (10.0 * log10 (meanPowerDensity * (xmax - xmin))), U" dB");
 }
 
@@ -100,7 +99,7 @@ double Ltas_getLocalPeakHeight (Ltas me, double environmentMin, double environme
 autoMatrix Ltas_to_Matrix (Ltas me) {
 	try {
 		autoMatrix thee = Thing_new (Matrix);
-		my structMatrix :: v_copy (thee.get());
+		my structMatrix :: v1_copy (thee.get());
 		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": not converted to Matrix.");
@@ -110,7 +109,7 @@ autoMatrix Ltas_to_Matrix (Ltas me) {
 autoLtas Matrix_to_Ltas (Matrix me) {
 	try {
 		autoLtas thee = Thing_new (Ltas);
-		my structMatrix :: v_copy (thee.get());   // because copying to a descendant of Matrix with additional members should not crash
+		my structMatrix :: v1_copy (thee.get());   // because copying to a descendant of Matrix with additional members should not crash
 		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": not converted to Ltas.");
