@@ -1,6 +1,6 @@
 /* PitchTier_to_Sound.h
  *
- * Copyright (C) 1992-2011,2015,2017 Paul Boersma
+ * Copyright (C) 1992-2011,2015-2017,2022 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ autoSound PitchTier_to_Sound_phonation (PitchTier me, double samplingFrequency,
 	 double adaptFactor, double maximumPeriod,
 	 double openPhase, double collisionPhase, double power1, double power2,
 	 bool hum);
-void PitchTier_playPart (PitchTier me, double tmin, double tmax, bool hum);
+void PitchTier_playPart (PitchTier me, double tmin, double tmax, bool hum);   // BUG: why no callback?
 void PitchTier_play (PitchTier me);
 void PitchTier_hum (PitchTier me);
 
