@@ -1,6 +1,6 @@
 /* RealTier.cpp
  *
- * Copyright (C) 1992-2012,2014-2021 Paul Boersma
+ * Copyright (C) 1992-2012,2014-2022 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -51,8 +51,8 @@ autoRealPoint RealPoint_create (double time, double value) {
 
 /********** class RealTier **********/
 
-void structRealTier :: v_info () {
-	structFunction :: v_info ();
+void structRealTier :: v1_info () {
+	structFunction :: v1_info ();
 	MelderInfo_writeLine (U"Number of points: ", our points.size);
 	MelderInfo_writeLine (U"Minimum value: ", RealTier_getMinimumValue (this));
 	MelderInfo_writeLine (U"Maximum value: ", RealTier_getMaximumValue (this));
@@ -163,10 +163,13 @@ double RealTier_getMaximumValue (RealTier me) {
 }
 
 double RealTier_getMinimumValue (RealTier me) {
+	Melder_assert (me);
 	double result = undefined;
 	integer n = my points.size;
 	for (integer i = 1; i <= n; i ++) {
+		Melder_assert (my points.at._elements);
 		RealPoint point = my points.at [i];
+		Melder_assert (point);
 		if (isundef (result) || point -> value < result)
 			result = point -> value;
 	}
@@ -543,7 +546,7 @@ autoRealTier RealTier_PointProcess_to_RealTier (RealTier me, PointProcess pp) {
 autoRealTier AnyRealTier_downto_RealTier (RealTier me) {
 	try {
 		autoRealTier thee = Thing_new (RealTier);
-		my structRealTier :: v_copy (thee.get());
+		my structRealTier :: v1_copy (thee.get());
 		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": not converted to RealTier.");
