@@ -74,7 +74,6 @@ static struct {
 	enum kMelder_asynchronicityLevel maximumAsynchronicity;
 	enum kMelder_inputSoundSystem inputSoundSystem;
 	enum kMelder_outputSoundSystem outputSoundSystem;
-	bool useInternalSpeaker;
 	double silenceBefore, silenceAfter;
 } preferences;
 
@@ -82,7 +81,6 @@ void Melder_audio_prefs () {
 	Preferences_addEnum (U"Audio.maximumAsynchronicity", & preferences. maximumAsynchronicity, kMelder_asynchronicityLevel, kMelder_asynchronicityLevel::DEFAULT);
 	Preferences_addEnum (U"Audio.inputSoundSystem", & preferences. inputSoundSystem, kMelder_inputSoundSystem, kMelder_inputSoundSystem::DEFAULT);
 	Preferences_addEnum (U"Audio.outputSoundSystem", & preferences. outputSoundSystem, kMelder_outputSoundSystem, kMelder_outputSoundSystem::DEFAULT);
-	Preferences_addBool (U"Audio.useInternalSpeaker", & preferences. useInternalSpeaker, true);
 	Preferences_addDouble (U"Audio.silenceBefore2", & preferences. silenceBefore, kMelderAudio_outputSilenceBefore_DEFAULT);
 	Preferences_addDouble (U"Audio.silenceAfter2", & preferences. silenceAfter, kMelderAudio_outputSilenceAfter_DEFAULT);
 }
@@ -110,12 +108,6 @@ enum kMelder_outputSoundSystem MelderAudio_getOutputSoundSystem () {
 	return preferences. outputSoundSystem;
 }
 
-void MelderAudio_setUseInternalSpeaker (bool useInternalSpeaker) {
-	MelderAudio_stopPlaying (MelderAudio_IMPLICIT);
-	preferences. useInternalSpeaker = useInternalSpeaker;
-}
-bool MelderAudio_getUseInternalSpeaker () { return preferences. useInternalSpeaker; }
-
 void MelderAudio_setOutputSilenceBefore (double silenceBefore) {
 	MelderAudio_stopPlaying (MelderAudio_IMPLICIT);
 	preferences. silenceBefore = silenceBefore;
@@ -432,7 +424,7 @@ static bool workProc (void *closure) {
 					Pa_AbortStream (my stream);
 					return flush ();
 				}
-			} else if (my samplesPlayed < my numberOfSamples + my sampleRate / 20) {   // allow the latency estimate to be 50 ms off.
+			} else if (my samplesPlayed < my numberOfSamples + my sampleRate / 2) {   // allow the latency estimate to be 500 ms off.
 				if (my callback && ! my callback (my closure, my samplesPlayed)) {
 					Pa_AbortStream (my stream);
 					return flush ();
@@ -552,7 +544,7 @@ static int thePaStreamCallback (const void *input, void *output,
 		if (Melder_debug == 20) Melder_casual (U"output overflow");
 	}
 	if (my samplesLeft > 0) {
-		integer dsamples = my samplesLeft > (integer) frameCount ? (integer) frameCount : my samplesLeft;
+		const integer dsamples = Melder_clippedRight ((integer) frameCount, my samplesLeft);
 		if (Melder_debug == 20) Melder_casual (U"play ", dsamples, U" ", Pa_GetStreamCpuLoad (my stream));
 		memset (output, '\0', 2 * frameCount * my numberOfChannels);
 		Melder_assert (my playBuffer);
@@ -990,6 +982,31 @@ static int theCoreaudioPropertyListener (unsigned int, unsigned int, const Audio
 }
 #endif
 
+static bool interruptedByEscapeKey () {
+	#if defined(_WIN32)
+		MSG event;
+		BOOL messageAvailable = PeekMessage (& event, nullptr, 0, 0, PM_REMOVE);
+		if (messageAvailable) {
+			trace (U"Windows message: ", event.message);
+			if (event. message == WM_KEYDOWN) {
+				trace (U"Windows key: ", event. wParam);
+				if (LOWORD (event. wParam) == VK_ESCAPE)
+					return true;
+			} else if (event. message == WM_LBUTTONDOWN
+				|| event.message == WM_NCLBUTTONDOWN)
+			{
+				// ignore all mouse events
+			} else {
+				// handle all other events, such as Chinese keyboard events
+				XtDispatchEvent (& event);
+				//TranslateMessage (& event);
+				//DispatchMessage (& event);
+			}
+		}
+	#endif
+	return false;
+}
+
 void MelderAudio_play16 (int16 *buffer, integer sampleRate, integer numberOfSamples, integer numberOfChannels,
 	bool (*playCallback) (void *playClosure, integer numberOfSamplesPlayed), void *playClosure)
 {
@@ -1019,6 +1036,7 @@ void MelderAudio_play16 (int16 *buffer, integer sampleRate, integer numberOfSamp
 		}
 	#endif
 	my playBuffer = buffer;   // 0-based, as all buffers are
+	int16 *playBuffer2 = nullptr;   // in case we have to redistribute up (not ideal)
 	my sampleRate = sampleRate;
 	my numberOfSamples = numberOfSamples;
 	my numberOfChannels = numberOfChannels;
@@ -1167,12 +1185,9 @@ void MelderAudio_play16 (int16 *buffer, integer sampleRate, integer numberOfSamp
 							}
 						}
 					#elif defined (_WIN32)
-						MSG event;
-						if (PeekMessage (& event, 0, 0, 0, PM_REMOVE) && event. message == WM_KEYDOWN) {
-							if (LOWORD (event. wParam) == VK_ESCAPE) {
-								my explicitStop = MelderAudio_EXPLICIT;
-								interrupted = true;
-							}
+						if (interruptedByEscapeKey ()) {
+							my explicitStop = MelderAudio_EXPLICIT;
+							interrupted = true;
 						}
 					#endif
 				}
@@ -1187,7 +1202,7 @@ void MelderAudio_play16 (int16 *buffer, integer sampleRate, integer numberOfSamp
 			#ifndef linux
 				Pa_AbortStream (my stream);
 			#endif
-		} else /* my asynchronicity == kMelder_asynchronicityLevel_ASYNCHRONOUS */ {
+		} else /* my asynchronicity == kMelder_asynchronicityLevel::ASYNCHRONOUS */ {
 			#if gtk
 				trace (U"g_idle_add");
 				my workProcId_gtk = g_idle_add (workProc_gtk, nullptr);
@@ -1196,7 +1211,7 @@ void MelderAudio_play16 (int16 *buffer, integer sampleRate, integer numberOfSamp
 			#elif cocoa
 				CFRunLoopTimerContext context = { 0, nullptr, nullptr, nullptr, nullptr };
 				my cocoaTimer = CFRunLoopTimerCreate (nullptr, CFAbsoluteTimeGetCurrent () + 0.02,
-					0.02, 0, 0, workProc_cocoa, & context);
+						0.02, 0, 0, workProc_cocoa, & context);
 				CFRunLoopAddTimer (CFRunLoopGetCurrent (), my cocoaTimer, kCFRunLoopCommonModes);
 			#endif
 			return;
@@ -1315,6 +1330,18 @@ void MelderAudio_play16 (int16 *buffer, integer sampleRate, integer numberOfSamp
 							if (err != MMSYSERR_NOERROR)
 								Melder_throw (U"Bad sound format even after reduction to 2 channels? Should not occur! Report bug to the author!");
 							MelderAudio_isPlaying = true;
+						} else if (my numberOfChannels == 1) {
+							/*
+							 * Retry with 2 channels.
+							 */
+							my numberOfChannels = 2;
+							waveFormat. nChannels = my numberOfChannels;
+							waveFormat. nBlockAlign = my numberOfChannels * waveFormat. wBitsPerSample / 8;
+							waveFormat. nAvgBytesPerSec = waveFormat. nBlockAlign * waveFormat. nSamplesPerSec;
+							err = waveOutOpen (& my hWaveOut, WAVE_MAPPER, & waveFormat, 0, 0, CALLBACK_NULL | WAVE_ALLOWSYNC);
+							if (err != MMSYSERR_NOERROR)
+								Melder_throw (U"Bad sound format even after expansion to 2 channels? Should not occur! Report bug to the author!");
+							MelderAudio_isPlaying = true;
 						} else {
 							Melder_throw (U"Bad sound format? Should not occur! Report bug to the author!");
 						}
@@ -1348,10 +1375,20 @@ void MelderAudio_play16 (int16 *buffer, integer sampleRate, integer numberOfSamp
 							}
 						}
 					}
+				} else if (numberOfChannels == 1 && my numberOfChannels == 2) {
+					playBuffer2 = Melder_malloc (int16, numberOfSamples * my numberOfChannels);
+					Melder_assert (playBuffer2);
+					int16 *in = & my playBuffer [0], *out = & playBuffer2 [0];
+					for (integer isamp = 1; isamp <= numberOfSamples; isamp ++) {
+						const int16 inValue = *in ++;
+						*out ++ = inValue;
+						*out ++ = inValue;
+					}
+					std::swap (my playBuffer, playBuffer2);
 				}
 
 				my waveHeader. dwFlags = 0;
-				my waveHeader. lpData = (char *) my playBuffer;
+				my waveHeader. lpData = playBuffer2 ? (char *) playBuffer2 : (char *) my playBuffer;
 				my waveHeader. dwBufferLength = my numberOfSamples * 2 * my numberOfChannels;
 				my waveHeader. dwLoops = 1;
 				my waveHeader. lpNext = nullptr;
@@ -1388,15 +1425,12 @@ void MelderAudio_play16 (int16 *buffer, integer sampleRate, integer numberOfSamp
 					my samplesPlayed = my numberOfSamples;
 				} else if (my asynchronicity <= kMelder_asynchronicityLevel::INTERRUPTABLE) {
 					while (! (my waveHeader. dwFlags & WHDR_DONE)) {
-						MSG event;
 						Sleep (10);
 						my samplesPlayed = (Melder_clock () - theStartingTime) * my sampleRate;
 						if (my callback && ! my callback (my closure, my samplesPlayed))
 							break;
-						if (my asynchronicity == kMelder_asynchronicityLevel::INTERRUPTABLE &&
-							PeekMessage (& event, 0, 0, 0, PM_REMOVE) && event. message == WM_KEYDOWN)
-						{
-							if (LOWORD (event. wParam) == VK_ESCAPE) {
+						if (my asynchronicity == kMelder_asynchronicityLevel::INTERRUPTABLE) {
+							if (interruptedByEscapeKey ()) {
 								my explicitStop = MelderAudio_EXPLICIT;
 								break;
 							}
